@@ -13,6 +13,13 @@ my %formats = (
 );
 
 use POSIX ();
+use Time::Local ();
+
+my $tzoffset = POSIX::strftime("%z", localtime) !~ /^[+-]\d{4}$/ && do {
+    my @t = localtime(time);
+    my $s = Time::Local::timegm(@t) - Time::Local::timelocal(@t);
+    sprintf '%+03d%02u', int($s/3600), $s % 3600;
+};
 
 sub call {
     my $self = shift;
@@ -35,9 +42,11 @@ sub log_line {
     my $h = Plack::Util::headers($headers);
 
     my $strftime = sub {
+        my ($fmt, @time) = @_;
+        $fmt =~ s/%z/$tzoffset/g if $tzoffset;
         my $old_locale = POSIX::setlocale(&POSIX::LC_ALL);
         POSIX::setlocale(&POSIX::LC_ALL, 'C');
-        my $out = POSIX::strftime(@_);
+        my $out = POSIX::strftime($fmt, @time);
         POSIX::setlocale(&POSIX::LC_ALL, $old_locale);
         return $out;
     };
@@ -106,6 +115,7 @@ sub _safe {
     $string;
 }
 
+1;
 
 __END__
 
